@@ -89,7 +89,7 @@ def init_flask(
         extra_jinja_vars
     )
     __init_db(config, default_models + models)
-    __init_login_manager()
+    __init_login_manager(config)
 
 
 def __init_logging(config: Type[Config]):
@@ -158,6 +158,8 @@ def __init_app(
     app.testing = config.TESTING
     app.config["TRAP_HTTP_EXCEPTIONS"] = True
     app.config["SERVER_NAME"] = Config.base_url().split("://", 1)[1]
+    if Config.BEHIND_PROXY:
+        app.config["PREFERRED_URL_SCHEME"] = "https"
     app.secret_key = config.FLASK_SECRET
     for blueprint_generator, blueprint_name in blueprint_generators:
         if blueprint_name in CREATED_BLUEPRINTS:
@@ -248,12 +250,13 @@ def __init_db(config: Type[Config], models: List[db.Model]):
             sys.exit(1)
 
 
-def __init_login_manager():
+def __init_login_manager(config: Type[Config]):
     """
     Initializes the login manager
+    :param config: The configuration to use
     :return: None
     """
-    login_manager.session_protection = "strong"
+    login_manager.session_protection = config.SESSION_PROTECTION
 
     # Set up login manager
     @login_manager.user_loader
